@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ class BatchModifyDomainInfoRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 批量修改的域名。
         :type Domains: list of str
         :param TemplateId: 模板ID。
@@ -48,7 +48,7 @@ false：关闭60天内禁止转移注册商锁定
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -58,7 +58,7 @@ class BatchModifyDomainInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -71,13 +71,6 @@ class BatchModifyDomainInfoResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class BatchStatus(AbstractModel):
@@ -86,7 +79,7 @@ class BatchStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 批量任务id
         :type LogId: int
         :param Status: 批量任务状态  doing：进行中  success：成功  failed：失败  partial_success：部分成功
@@ -108,7 +101,7 @@ class BatchStatus(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -118,7 +111,7 @@ class CertificateInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CertificateCode: 证件号码。
         :type CertificateCode: str
         :param CertificateType: 证件类型。
@@ -168,7 +161,7 @@ GZJGZY: 公证机构执业证。
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -178,7 +171,7 @@ class CheckBatchStatusRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogIds: 操作日志 ID数组，最多 200 个
         :type LogIds: list of int non-negative
         """
@@ -192,7 +185,7 @@ class CheckBatchStatusRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -202,7 +195,7 @@ class CheckBatchStatusResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param StatusSet: 批量任务状态集
         :type StatusSet: list of BatchStatus
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -220,13 +213,6 @@ class CheckBatchStatusResponse(AbstractModel):
                 obj._deserialize(item)
                 self.StatusSet.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CheckDomainRequest(AbstractModel):
@@ -235,10 +221,10 @@ class CheckDomainRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainName: 所查询域名名称
         :type DomainName: str
-        :param Period: 年限
+        :param Period: 年限。该参数为空时无法查询溢价词域名
         :type Period: str
         """
         self.DomainName = None
@@ -253,7 +239,7 @@ class CheckDomainRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -263,7 +249,7 @@ class CheckDomainResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainName: 所查询域名名称
         :type DomainName: str
         :param Available: 是否能够注册
@@ -328,13 +314,6 @@ class CheckDomainResponse(AbstractModel):
         self.Period = params.get("Period")
         self.RecordSupport = params.get("RecordSupport")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ContactInfo(AbstractModel):
@@ -343,7 +322,7 @@ class ContactInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param OrganizationNameCN: 注册人（中文）
         :type OrganizationNameCN: str
         :param OrganizationName: 注册人（英文）
@@ -417,7 +396,7 @@ class ContactInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -427,7 +406,7 @@ class CreateDomainBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID。详情请查看：[获取模板列表](https://cloud.tencent.com/document/product/242/48940)
         :type TemplateId: str
         :param Period: 购买域名的年限，可选值：[1-10]
@@ -463,7 +442,7 @@ class CreateDomainBatchRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -473,7 +452,7 @@ class CreateDomainBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 批量日志ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type LogId: int
@@ -487,13 +466,6 @@ class CreateDomainBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateTemplateRequest(AbstractModel):
@@ -502,7 +474,7 @@ class CreateTemplateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ContactInfo: 联系人信息
         :type ContactInfo: :class:`tencentcloud.domain.v20180808.models.ContactInfo`
         :param CertificateInfo: 证件信息
@@ -524,7 +496,7 @@ class CreateTemplateRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -534,7 +506,7 @@ class CreateTemplateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Template: 模板信息
         :type Template: :class:`tencentcloud.domain.v20180808.models.TemplateInfo`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -549,13 +521,6 @@ class CreateTemplateResponse(AbstractModel):
             self.Template = TemplateInfo()
             self.Template._deserialize(params.get("Template"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DeleteTemplateRequest(AbstractModel):
@@ -564,7 +529,7 @@ class DeleteTemplateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID
         :type TemplateId: str
         """
@@ -578,7 +543,7 @@ class DeleteTemplateRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -588,7 +553,7 @@ class DeleteTemplateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -597,13 +562,6 @@ class DeleteTemplateResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeBatchOperationLogDetailsRequest(AbstractModel):
@@ -612,7 +570,7 @@ class DescribeBatchOperationLogDetailsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID。
         :type LogId: int
         :param Offset: 偏移量，默认为0。
@@ -634,7 +592,7 @@ class DescribeBatchOperationLogDetailsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -644,7 +602,7 @@ class DescribeBatchOperationLogDetailsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 总数量。
         :type TotalCount: int
         :param DomainBatchDetailSet: 日志详情列表。
@@ -667,13 +625,6 @@ class DescribeBatchOperationLogDetailsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.DomainBatchDetailSet.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeBatchOperationLogsRequest(AbstractModel):
@@ -682,7 +633,7 @@ class DescribeBatchOperationLogsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Offset: 偏移量，默认为0。
         :type Offset: int
         :param Limit: 返回数量，默认为20，最大值为200。
@@ -700,7 +651,7 @@ class DescribeBatchOperationLogsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -710,7 +661,7 @@ class DescribeBatchOperationLogsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 总数量
         :type TotalCount: int
         :param DomainBatchLogSet: 日志列表
@@ -733,13 +684,6 @@ class DescribeBatchOperationLogsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.DomainBatchLogSet.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeDomainBaseInfoRequest(AbstractModel):
@@ -748,7 +692,7 @@ class DescribeDomainBaseInfoRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domain: 域名
         :type Domain: str
         """
@@ -762,7 +706,7 @@ class DescribeDomainBaseInfoRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -772,7 +716,7 @@ class DescribeDomainBaseInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainInfo: 域名信息
         :type DomainInfo: :class:`tencentcloud.domain.v20180808.models.DomainBaseInfo`
         :param Uin: 用户Uin
@@ -792,13 +736,6 @@ class DescribeDomainBaseInfoResponse(AbstractModel):
             self.DomainInfo._deserialize(params.get("DomainInfo"))
         self.Uin = params.get("Uin")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeDomainNameListRequest(AbstractModel):
@@ -807,7 +744,7 @@ class DescribeDomainNameListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Offset: 偏移量，默认为0
         :type Offset: int
         :param Limit: 返回数量，默认为20，取值范围[1,100]
@@ -825,7 +762,7 @@ class DescribeDomainNameListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -835,7 +772,7 @@ class DescribeDomainNameListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainSet: 域名信息集合
 注意：此字段可能返回 null，表示取不到有效值。
         :type DomainSet: list of DomainList
@@ -858,13 +795,6 @@ class DescribeDomainNameListResponse(AbstractModel):
                 self.DomainSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeDomainPriceListRequest(AbstractModel):
@@ -873,7 +803,7 @@ class DescribeDomainPriceListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TldList: 查询价格的后缀列表。默认则为全部后缀
         :type TldList: list of str
         :param Year: 查询购买的年份，默认会列出所有年份的价格
@@ -895,7 +825,7 @@ class DescribeDomainPriceListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -905,7 +835,7 @@ class DescribeDomainPriceListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PriceList: 域名价格列表
         :type PriceList: list of PriceInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -923,13 +853,6 @@ class DescribeDomainPriceListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PriceList.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeTemplateListRequest(AbstractModel):
@@ -938,7 +861,7 @@ class DescribeTemplateListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Offset: 偏移量，默认为0。
         :type Offset: int
         :param Limit: 返回数量，默认为20，最大值为100。
@@ -968,7 +891,7 @@ class DescribeTemplateListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -978,7 +901,7 @@ class DescribeTemplateListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 模板数量。
         :type TotalCount: int
         :param TemplateSet: 模板详细信息列表。
@@ -1000,13 +923,6 @@ class DescribeTemplateListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.TemplateSet.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeTemplateRequest(AbstractModel):
@@ -1015,7 +931,7 @@ class DescribeTemplateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID
         :type TemplateId: str
         """
@@ -1029,7 +945,7 @@ class DescribeTemplateRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1039,7 +955,7 @@ class DescribeTemplateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Template: 模板信息
         :type Template: :class:`tencentcloud.domain.v20180808.models.TemplateInfo`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1054,13 +970,6 @@ class DescribeTemplateResponse(AbstractModel):
             self.Template = TemplateInfo()
             self.Template._deserialize(params.get("Template"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DomainBaseInfo(AbstractModel):
@@ -1069,7 +978,7 @@ class DomainBaseInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainId: 域名资源ID。
         :type DomainId: str
         :param DomainName: 域名名称。
@@ -1079,6 +988,7 @@ NotUpload：未实名认证
 InAudit：实名审核中
 Approved：实名审核通过
 Reject：实名审核失败
+NoAudit: 无需实名认证
         :type RealNameAuditStatus: str
         :param RealNameAuditUnpassReason: 域名实名认证不通过原因。
 注意：此字段可能返回 null，表示取不到有效值。
@@ -1176,7 +1086,7 @@ false：关闭锁定
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1186,7 +1096,7 @@ class DomainBatchDetailSet(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Id: 详情ID
         :type Id: int
         :param Domain: 域名
@@ -1224,7 +1134,7 @@ success  操作成功。
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1234,7 +1144,7 @@ class DomainBatchLogSet(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param Number: 数量
@@ -1262,7 +1172,7 @@ done 执行完成。
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1272,7 +1182,7 @@ class DomainList(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsPremium: 是否是溢价域名：
 ture 是    
 false 不是
@@ -1334,7 +1244,7 @@ TransferFailed：转入失败
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1344,7 +1254,7 @@ class ModifyDomainDNSBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 批量操作的域名。
         :type Domains: list of str
         :param Dns: 域名DNS 数组。
@@ -1362,7 +1272,7 @@ class ModifyDomainDNSBatchRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1372,7 +1282,7 @@ class ModifyDomainDNSBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID。
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1385,13 +1295,6 @@ class ModifyDomainDNSBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ModifyDomainOwnerBatchRequest(AbstractModel):
@@ -1400,25 +1303,29 @@ class ModifyDomainOwnerBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 要过户的域名。
         :type Domains: list of str
         :param NewOwnerUin: 转入账户的uin。
         :type NewOwnerUin: str
+        :param TransferDns: 是否同时转移对应的 DNS 解析域名，默认false
+        :type TransferDns: bool
         """
         self.Domains = None
         self.NewOwnerUin = None
+        self.TransferDns = None
 
 
     def _deserialize(self, params):
         self.Domains = params.get("Domains")
         self.NewOwnerUin = params.get("NewOwnerUin")
+        self.TransferDns = params.get("TransferDns")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1428,7 +1335,7 @@ class ModifyDomainOwnerBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志id
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1441,13 +1348,6 @@ class ModifyDomainOwnerBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class PriceInfo(AbstractModel):
@@ -1456,7 +1356,7 @@ class PriceInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Tld: 域名后缀，例如.com
         :type Tld: str
         :param Year: 购买年限，范围[1-10]
@@ -1486,7 +1386,7 @@ class PriceInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1496,7 +1396,7 @@ class RenewDomainBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Period: 域名续费的年限。
         :type Period: int
         :param Domains: 批量续费的域名。
@@ -1525,7 +1425,7 @@ class RenewDomainBatchRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1535,7 +1435,7 @@ class RenewDomainBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 操作日志ID。
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1548,13 +1448,6 @@ class RenewDomainBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class SetDomainAutoRenewRequest(AbstractModel):
@@ -1563,7 +1456,7 @@ class SetDomainAutoRenewRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainId: 域名ID。
         :type DomainId: str
         :param AutoRenew: AutoRenew 有三个可选值：
@@ -1584,7 +1477,7 @@ class SetDomainAutoRenewRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1594,7 +1487,7 @@ class SetDomainAutoRenewResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1603,13 +1496,6 @@ class SetDomainAutoRenewResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class TemplateInfo(AbstractModel):
@@ -1618,7 +1504,7 @@ class TemplateInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID
         :type TemplateId: str
         :param AuditStatus: 认证状态：未实名认证:NotUpload, 实名审核中:InAudit，已实名认证:Approved，实名审核失败:Reject
@@ -1676,7 +1562,7 @@ class TemplateInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1686,7 +1572,7 @@ class TransferInDomainBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 转入的域名名称数组。
         :type Domains: list of str
         :param PassWords: 域名转移码数组。
@@ -1724,7 +1610,7 @@ false：关闭60天内禁止转移注册商锁定
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1734,7 +1620,7 @@ class TransferInDomainBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1747,13 +1633,6 @@ class TransferInDomainBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class TransferProhibitionBatchRequest(AbstractModel):
@@ -1762,7 +1641,7 @@ class TransferProhibitionBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 批量操作的域名。
         :type Domains: list of str
         :param Status: 是否开启禁止域名转移。
@@ -1782,7 +1661,7 @@ False：关闭禁止域名转移状态。
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1792,7 +1671,7 @@ class TransferProhibitionBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1805,13 +1684,6 @@ class TransferProhibitionBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class UpdateProhibitionBatchRequest(AbstractModel):
@@ -1820,7 +1692,7 @@ class UpdateProhibitionBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 批量操作的域名。
         :type Domains: list of str
         :param Status: 是否开启禁止域名更新。
@@ -1840,7 +1712,7 @@ False：关闭禁止域名更新状态。
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1850,7 +1722,7 @@ class UpdateProhibitionBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1863,13 +1735,6 @@ class UpdateProhibitionBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class UploadImageRequest(AbstractModel):
@@ -1878,7 +1743,7 @@ class UploadImageRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ImageFile: 资质照片，照片的base64编码。
         :type ImageFile: str
         """
@@ -1892,7 +1757,7 @@ class UploadImageRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1902,7 +1767,7 @@ class UploadImageResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AccessUrl: 资质照片地址。
         :type AccessUrl: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1914,11 +1779,4 @@ class UploadImageResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.AccessUrl = params.get("AccessUrl")
-        self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
\ No newline at end of file
+        self.RequestId = params.get("RequestId")
\ No newline at end of file
